procedure add_lc_labels(wks,map,lat_values,lon_values)
local nlat, lat1_ndc, lat2_ndc, lon1_ndc, lon2_ndc,slope,txres, \
PI, RAD_TO_DEG, dum_lft, dum_rgt, dum_bot, rotate_val, minlat, maxlat, \
minlon, maxlon
begin
  PI         = 3.14159
  RAD_TO_DEG = 180./PI

  minlat=lat_values(0)
  maxlat=lat_values(dimsizes(lat_values)-1)
  minlon=lon_values(0)
  maxlon=lon_values(dimsizes(lon_values)-1)

;---Determine whether we are in northern or southern hemisphere
  if(minlat.ge.0.and.maxlat.gt.0) then
    HEMISPHERE = "NH"
  else
    HEMISPHERE = "SH"
  end if

;---Pick some "nice" values for the latitude labels.
  ;!!SW lat_values = ispan(toint(minlat),toint(maxlat),10) * 1.
  nlat       = dimsizes(lat_values)
;
; We need to get the slope of the left and right min/max longitude lines.
; Use NDC coordinates to do this.
;
  lat1_ndc = new(1,float)
  lon1_ndc = new(1,float)
  lat2_ndc = new(1,float)
  lon2_ndc = new(1,float)
  datatondc(map,minlon,lat_values(0),lon1_ndc,lat1_ndc)
  datatondc(map,minlon,lat_values(nlat-1),lon2_ndc,lat2_ndc)
  slope_lft = (lat2_ndc-lat1_ndc)/(lon2_ndc-lon1_ndc)

  datatondc(map,maxlon,lat_values(0),lon1_ndc,lat1_ndc)
  datatondc(map,maxlon,lat_values(nlat-1),lon2_ndc,lat2_ndc)
  slope_rgt = (lat2_ndc-lat1_ndc)/(lon2_ndc-lon1_ndc)

;---Set some text resources
  txres               = True
  txres@txFontHeightF = 0.01
  txres@txPosXF       = 0.1
;
; Loop through lat values, and attach labels to the left and
; right edges of the masked LC plot.  The labels will be 
; rotated to fit the line better.
;
  dum_lft = new(nlat,graphic)    ; Dummy array to hold attached strings.
  dum_rgt = new(nlat,graphic)    ; Dummy array to hold attached strings.
;!!SW  do n=0,nlat-1
  do n=1,nlat-2
;---Left label
    if(HEMISPHERE.eq."NH") then
      rotate_val = -90
      direction  = "N"
    else
      rotate_val = 90
      direction  = "S"
    end if

; Add extra white space to labels.
;!!SW    lat_label_lft = abs(lat_values(n)) + "~S~o~N~" + direction + \
    lat_label_lft = abs(lat_values(n)) + direction + \
                    "          "   
;!!SW    lat_label_rgt = "          "  + abs(lat_values(n)) + "~S~o~N~" + \
    lat_label_rgt = "          "  + abs(lat_values(n)) + direction

    txres@txAngleF = RAD_TO_DEG * atan(slope_lft) + rotate_val
    ;!!SW dum_lft(n) = gsn_add_text(wks,map,lat_label_lft,minlon,lat_values(n),txres)

;---Right label
    if(HEMISPHERE.eq."NH") then
      rotate_val = 90
    else
      rotate_val = -90
    end if
    txres@txAngleF = RAD_TO_DEG * atan(slope_rgt) + rotate_val
    dum_rgt(n) = gsn_add_text(wks,map,lat_label_rgt,maxlon,lat_values(n),txres)
  end do

;----------------------------------------------------------------------
; Now do longitude labels. These are harder because we're not
; adding them to a straight line.
;
; Loop through lon values, and attach labels to the bottom edge
; for northern hemisphere, or top edge for southern hemisphere.
;
  delete(txres@txPosXF)
  txres@txPosYF = -5.0

;---Pick some "nice" values for the longitude labels.
  ;!!SW lon_values = ispan(toint(minlon+10),toint(maxlon-10),10) * 1.
  nlon       = dimsizes(lon_values)
  lon_values = where(lon_values.gt.180,360-lon_values,lon_values)

  dum_bot = new(nlon,graphic)    ; Dummy array to hold attached strings.

  lon_labels = "" + lon_values
  lon_labels = where(lon_values.lt.0, abs(lon_values) + \
                    "W",""+lon_labels)
;;!!SW                    "~S~o~N~W",""+lon_labels)
  lon_labels = where(lon_values.eq.0,"0",lon_labels)
  lon_labels = where(lon_values.gt.0,lon_values + "E",lon_labels)
;;!!SW  lon_labels = where(lon_values.gt.0,lon_values + "~S~o~N~E",lon_labels)
  if(HEMISPHERE.eq."NH") then
    lon_labels = "  ~C~  ~C~" + lon_labels
    lat_val   = minlat
  else
    lon_labels = lon_labels + "~C~ ~C~ "
    lat_val    = maxlat
  end if

  do n=1,nlon-2
;!!SW  do n=0,nlon-1


;
; For each longitude label, we need to figure out how much to rotate
; it, so get the approximate slope at that point.
;
    if(HEMISPHERE.eq."NH") then
;---Add labels to bottom of LC plot
      datatondc(map,lon_values(n)-0.25,minlat,lon1_ndc,lat1_ndc)
      datatondc(map,lon_values(n)+0.25,minlat,lon2_ndc,lat2_ndc)
    else
;---Add labels to top of LC plot
      datatondc(map,lon_values(n)+0.25,maxlat,lon1_ndc,lat1_ndc)
      datatondc(map,lon_values(n)-0.25,maxlat,lon2_ndc,lat2_ndc)
    end if
    slope_bot = (lat1_ndc-lat2_ndc)/(lon1_ndc-lon2_ndc)
    txres@txAngleF  = atan(slope_bot) * RAD_TO_DEG
;
; Create longitude label. Add extra carriage returns to
; move label away from plot.
;

;---Attach to map.
    dum_bot(n) = gsn_add_text(wks,map,lon_labels(n),lon_values(n),\
                              lat_val,txres)
  end do
end