#!/bin/bash

# calculates winter aggregate of one file with monthly data or individual monthly files with /esarchive structure
# new time axis will refer to last month of winter, e.g. for a winter mean DJF the year of the time axis will the year of Feb

module load CDO

infile=$1
if [ -e $infile ]; then
    ext=`echo $infile | sed -e 's@.*\.@.@g'`
    filename=`basename $infile $ext`
else 
    filename=$1
    ext=.nc
    if [ $# -ne 5 ]; then
	echo "need 5 input parameters for individual files"
	echo "./winter_aggregate.bash infile period operation startyear endyear" 
	exit
    fi
fi

period=$2
op=$3
sy=$4
ey=$5

if [ $# -ne 1 ] && [ $# -ne 2 ] && [ $# -ne 3 ] && [ $# -ne 5 ]; then
    echo "either 1,2,3 or 5 arguments expected"
    echo "./winter_aggregate.bash infile period operation startyear endyear" 
    exit
fi

if [ $# -lt 5 ]; then
    sy=$((`cdo -s showyear -seltimestep,1 $infile` + 1))
    nt=$(cdo -s ntime $infile)
    ey=$(cdo -s showyear -seltimestep,$nt $infile)
    if [ $# -lt 3 ]; then
	op=mean
	if [ $# -lt 2 ]; then
	    period=DJF
	fi
    fi
fi 
echo winter aggregate over
echo $period $sy $ey
echo ...

case $period in 
    DJF)
	w1m=12
	w2m=1,2
	;;
    DJFM)
	w1m=12
	w2m=1,2,3
	;;
    ONDJFM)
	w1m=10,11,12
	w2m=1,2,3
	;;
    *)
	echo "period has to be DJF, DJFM, ONDJFM"
	exit
	;;
esac

t=tmp/DJF
rm -rf $t
mkdir -p $t


    for ((y=$sy; y<=$ey; y++))
    do
	y1=`expr $y - 1`
	if [ -e $infile ]; then
	    cdo -s selmon,$w1m -selyear,$y1 $1 $t/d
	    cdo -s selmon,$w2m -selyear,$y $1 $t/jf
	else
	    for m in $(echo $w1m | sed "s/,/ /g")
	    do
		cdo -s cat ${filename}_${y1}${m}$ext $t/d
	    done
	    for m in $(echo $w2m | sed "s/,/ /g")
	    do
		cdo -s cat ${filename}_${y}0${m}$ext $t/jf
	    done
	fi
	cdo -s mergetime $t/d $t/jf $t/$y
	cdo -s tim$op $t/$y $t/$y.ag
	rm -rf $t/d $t/jf
    done

outfile=${filename}.${sy}-${ey}.${period}${op}$ext
rm -f ${outfile}
cdo -s mergetime $t/????.ag $outfile

rm -rf $t
